@@ -16,6 +16,7 @@
 #' @param annotations a character vector
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
+#' @param text.size numeric size of text in the plot decorations.
 #' @param ... other arguments passed to e_response()
 #'
 #' @return a \code{ggplot} object.
@@ -29,6 +30,7 @@ e_rsp_plot <- function(spct,
                        label.qty,
                        annotations,
                        norm,
+                       text.size,
                        ...) {
   if (!is.response_spct(spct)) {
     stop("e_Rsp_plot() can only plot response_spct objects.")
@@ -102,8 +104,8 @@ e_rsp_plot <- function(spct,
         if (idx == "summary") {
           scale.factor <- 1 / summary.value
         } else {
-          scale.factor <- 1 / spct[idx, "s.e.response"]
-          norm <- spct[idx, "w.length"]
+          scale.factor <- 1 / as.numeric(spct[idx, "s.e.response"])
+          norm <- as.numeric(spct[idx, "w.length"])
         }
       } else if (is.numeric(norm) && norm >= min(spct) && norm <= max(spct)) {
         scale.factor <- 1 / interpolate_spct(spct, norm)[["s.e.response"]]
@@ -162,7 +164,8 @@ e_rsp_plot <- function(spct,
                             x.min = min(spct),
                             annotations = annotations,
                             label.qty = label.qty,
-                            summary.label = rsp.label)
+                            summary.label = rsp.label,
+                            text.size = text.size)
 
   if (!is.na(exposure.label)) {
     plot <- plot +  annotate("text",
@@ -175,7 +178,8 @@ e_rsp_plot <- function(spct,
   }
 
   if (!is.null(annotations) &&
-      length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide"), annotations)) > 0L) {
+      length(intersect(c("boxes", "segments", "labels", "summaries",
+                         "colour.guide"), annotations)) > 0L) {
     y.limits <- c(0, y.max * 1.25)
     x.limits <- c(min(spct) - spread(spct) * 0.025, NA)
   } else {
@@ -205,6 +209,7 @@ e_rsp_plot <- function(spct,
 #' @param annotations a character vector
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
+#' @param text.size numeric size of text in the plot decorations.
 #' @param ... other arguments passed to q_response()
 #'
 #' @return a \code{ggplot} object.
@@ -218,6 +223,7 @@ q_rsp_plot <- function(spct,
                        label.qty,
                        annotations,
                        norm,
+                       text.size,
                        ...) {
   if (!is.response_spct(spct)) {
     stop("q_Rsp_plot() can only plot response_spct objects.")
@@ -291,8 +297,8 @@ q_rsp_plot <- function(spct,
         if (idx == "summary") {
           scale.factor <- 1 / summary.value
         } else {
-          scale.factor <- 1 / spct[idx, "s.q.response"]
-          norm <- spct[idx, "w.length"]
+          scale.factor <- 1 / as.numeric(spct[idx, "s.q.response"])
+          norm <- as.numeric(spct[idx, "w.length"])
         }
       } else if (is.numeric(norm) && norm >= min(spct) && norm <= max(spct)) {
         scale.factor <- 1 / interpolate_spct(spct, norm)$s.q.response
@@ -350,7 +356,8 @@ q_rsp_plot <- function(spct,
                             x.min = min(spct),
                             annotations = annotations,
                             label.qty = label.qty,
-                            summary.label = rsp.label)
+                            summary.label = rsp.label,
+                            text.size = text.size)
 
   if (!is.na(exposure.label)) {
     plot <- plot +  annotate("text",
@@ -363,7 +370,8 @@ q_rsp_plot <- function(spct,
   }
 
   if (!is.null(annotations) &&
-      length(intersect(c("boxes", "segments", "labels", "summaries", "colour.guide"), annotations)) > 0L) {
+      length(intersect(c("boxes", "segments", "labels", "summaries",
+                         "colour.guide"), annotations)) > 0L) {
     y.limits <- c(0, y.max * 1.25)
     x.limits <- c(min(spct) - spread(spct) * 0.025, NA)
   } else {
@@ -375,8 +383,6 @@ q_rsp_plot <- function(spct,
 
 }
 
-
-
 #' Plot a response spectrum, especialization of generic plot function.
 #'
 #' This function returns a ggplot object with an annotated plot of a
@@ -398,6 +404,7 @@ q_rsp_plot <- function(spct,
 #' @param annotations a character vector
 #' @param norm numeric normalization wavelength (nm) or character string "max"
 #'   for normalization at the wavelength of highest peak.
+#' @param text.size numeric size of text in the plot decorations.
 #'
 #' @return a \code{ggplot} object.
 #'
@@ -415,23 +422,42 @@ q_rsp_plot <- function(spct,
 #'
 plot.response_spct <-
   function(x, ...,
-           w.band=getOption("photobiology.plot.bands", default=list(UVC(), UVB(), UVA(), PAR())),
+           w.band=getOption("photobiology.plot.bands",
+                            default=list(UVC(), UVB(), UVA(), PAR())),
            range=NULL,
            unit.out=getOption("photobiology.radiation.unit", default="energy"),
            pc.out=FALSE,
            label.qty="total",
            annotations=getOption("photobiology.plot.annotations",
-                                 default = c("boxes", "labels", "summaries", "colour.guide", "peaks")),
-           norm = "max" ) {
+                                 default = c("boxes", "labels", "summaries",
+                                             "colour.guide", "peaks")),
+           norm = "max",
+           text.size = 2.5) {
     if ("color.guide" %in% annotations) {
       annotations <- c(setdiff(annotations, "color.guide"), "colour.guide")
     }
+    if (is.null(w.band)) {
+      if (is.null(range)) {
+        w.band <- photobiology::waveband(x)
+      } else if (is.waveband(range)) {
+        w.band <- range
+      } else {
+        w.band <-  photobiology::waveband(range, wb.name = "Total")
+      }
+    }
+
     if (unit.out=="photon" || unit.out=="quantum") {
       out.ggplot <- q_rsp_plot(spct=x, w.band=w.band, range=range,
-                               pc.out=pc.out, label.qty=label.qty, annotations=annotations, norm = norm, ...)
+                               pc.out=pc.out, label.qty=label.qty,
+                               annotations=annotations, norm = norm,
+                               text.size = text.size,
+                               ...)
     } else if (unit.out=="energy") {
       out.ggplot <- e_rsp_plot(spct=x, w.band=w.band, range=range,
-                               pc.out=pc.out, label.qty=label.qty, annotations=annotations, norm = norm, ...)
+                               pc.out=pc.out, label.qty=label.qty,
+                               annotations=annotations, norm = norm,
+                               text.size = text.size,
+                               ...)
     } else {
       stop("Invalid 'unit.out' argument value: '", unit.out, "'")
     }
